"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
var $ = require("jquery");
require("signalr");
var Promise = require("bluebird");
var inversify_1 = require("inversify");
var ts_smart_logger_1 = require("ts-smart-logger");
var definitions_interface_1 = require("../../definitions.interface");
var base_channel_service_1 = require("../base-channel.service");
var util_1 = require("../../util");
var channel_interface_1 = require("../channel.interface");
var SignalRChannel = /** @class */ (function (_super) {
    __extends(SignalRChannel, _super);
    function SignalRChannel() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.signalRInitTasks = new Map();
        return _this;
    }
    SignalRChannel_1 = SignalRChannel;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {AnyT} config
     */
    SignalRChannel.prototype.connect = function (ip, config) {
        var _this = this;
        var hubUrl = "" + this.settings.signalRUrl + ip;
        // We need to load the script at the any case
        this.signalRScriptTask = this.signalRScriptTask || util_1.createScript({ src: hubUrl });
        this.cancelInitTask(ip);
        this.signalRInitTasks.set(ip, 
        // Need to wrap the script loader promise because of chain cancellation
        new Promise(function (resolve) { return _this.signalRScriptTask.then(resolve); }) // This new promise instance may be canceled!
            .then(function () { return _this.onSignalRInitialize(ip, hubUrl); }));
    };
    /**
     * @stable [11.12.2018]
     * @param {string} ip
     */
    SignalRChannel.prototype.disconnect = function (ip) {
        this.cancelInitTask(ip);
        this.unregisterClient(this.prepareIp(ip));
    };
    /**
     * @stable [11.12.2018]
     * @param {string} ip
     * @param {string} event0
     * @param {AnyT} messages
     */
    SignalRChannel.prototype.emitEvent = function (ip, event0) {
        var messages = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            messages[_i - 2] = arguments[_i];
        }
        _super.prototype.emitEvent.apply(this, [this.prepareIp(ip), event0].concat(messages));
    };
    /**
     * @stable [11.12.2018]
     * @param {string} ip
     * @param {AnyT} messages
     */
    SignalRChannel.prototype.emitChannelEvent = function (ip, messages) {
        _super.prototype.emitChannelEvent.call(this, this.prepareIp(ip), messages);
    };
    /**
     * @stable [11.12.2018]
     * @param {string} ip
     * @param {string} hubUrl
     */
    SignalRChannel.prototype.onSignalRInitialize = function (ip, hubUrl) {
        var hubName = this.prepareIp(ip);
        $.connection.hub.url = hubUrl;
        Reflect.set($.connection.hub, 'baseUrl', this.settings.signalRUrl);
        var disconnectCallback;
        var isDisconnected = false;
        this.registerClient(hubName, {
            on: function (event, callback) {
                var _this = this;
                switch (event) {
                    case channel_interface_1.CHANNEL_CONNECT_EVENT:
                        $.connection.hub.start().done(function () {
                            if (!isDisconnected) {
                                callback();
                                $.connection.hub.received(function (data) { return _this.onMessage(hubName, definitions_interface_1.UNDEF, data); });
                            }
                        });
                        break;
                    case channel_interface_1.CHANNEL_DISCONNECT_EVENT:
                        disconnectCallback = function () {
                            isDisconnected = true;
                            callback();
                        };
                        break;
                }
            },
            emit: function (event) {
                var args = [];
                for (var _i = 1; _i < arguments.length; _i++) {
                    args[_i - 1] = arguments[_i];
                }
                switch (event) {
                    case channel_interface_1.CHANNEL_SEND_EVENT:
                        try {
                            $.connection.hub.send(args[0]);
                        }
                        catch (e) {
                            SignalRChannel_1.logger.error("[$SignalRChannel][onSignalRInitialize] An error occurred during send a message! The hub: " + hubName + ".", e);
                        }
                        break;
                }
            },
            close: function () {
                if (util_1.isFn(disconnectCallback)) {
                    disconnectCallback();
                }
                $.connection.hub.stop(false);
            },
        });
    };
    /**
     * @stable [11.12.2018]
     * @param {string} ip
     * @returns {string}
     */
    SignalRChannel.prototype.prepareIp = function (ip) {
        return "signalr:" + ip;
    };
    /**
     * @stable [11.12.2018]
     * @param {string} ip
     */
    SignalRChannel.prototype.cancelInitTask = function (ip) {
        if (this.signalRInitTasks.has(ip)) {
            this.signalRInitTasks.get(ip).cancel();
            this.signalRInitTasks.delete(ip);
        }
    };
    var SignalRChannel_1;
    SignalRChannel.logger = ts_smart_logger_1.LoggerFactory.makeLogger('SignalRChannel');
    SignalRChannel = SignalRChannel_1 = __decorate([
        inversify_1.injectable()
    ], SignalRChannel);
    return SignalRChannel;
}(base_channel_service_1.BaseChannel));
exports.SignalRChannel = SignalRChannel;
//# sourceMappingURL=signalr-channel.service.js.map