"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var util_1 = require("../../../util");
var configurations_definitions_interface_1 = require("../../../configurations-definitions.interface");
var UniversalLayoutBuilder = /** @class */ (function () {
    /**
     * @stable [22.10.2018]
     * @param {ILayoutViewBuilder<TNode>} layoutViewBuilder
     */
    function UniversalLayoutBuilder(layoutViewBuilder) {
        this.layoutViewBuilder = layoutViewBuilder;
        this.layoutId = util_1.uuid();
    }
    /**
     * @stable [22.10.2018]
     * @param {IUniversalLayoutBuilderConfiguration<TNode>} layoutConfig
     * @returns {TNode}
     */
    UniversalLayoutBuilder.prototype.build = function (layoutConfig) {
        this.index = 0; // Framework keys magic
        return this.buildLayout(layoutConfig);
    };
    /**
     * @stable [22.10.2018]
     * @param {UniversalLayoutBuilderChildrenT<TNode>} item
     * @returns {string}
     */
    UniversalLayoutBuilder.prototype.getClonedItemKey = function (item) {
        return this.newKey;
    };
    /**
     * @stable [22.10.2018]
     * @param {IUniversalLayoutBuilderConfiguration<TNode>} layoutConfig
     * @returns {TNode}
     */
    UniversalLayoutBuilder.prototype.buildLayout = function (layoutConfig) {
        if (layoutConfig.layout === configurations_definitions_interface_1.LayoutBuilderTypeEnum.HORIZONTAL) {
            return this.buildHorizontalLayout(layoutConfig);
        }
        return this.buildVerticalLayout(layoutConfig);
    };
    /**
     * @stable [22.10.2018]
     * @param {IUniversalLayoutBuilderConfiguration<TNode>} layoutConfig
     * @returns {TNode}
     */
    UniversalLayoutBuilder.prototype.buildHorizontalLayout = function (layoutConfig) {
        var _this = this;
        var children = [];
        var filteredItems = this.getDefinedChildren(layoutConfig);
        filteredItems.forEach(function (item, index) {
            children.push(_this.tryCloneItem(item, layoutConfig));
            if (index < filteredItems.length - 1) {
                children.push(_this.layoutViewBuilder.buildSeparatorView(_this.key));
            }
        });
        return this.layoutViewBuilder.buildRowView(this.key, children, layoutConfig);
    };
    /**
     * @stable [22.10.2018]
     * @param {IUniversalLayoutBuilderConfiguration<TNode>} layoutConfig
     * @returns {TNode}
     */
    UniversalLayoutBuilder.prototype.buildVerticalLayout = function (layoutConfig) {
        var _this = this;
        return this.layoutViewBuilder.buildColumnView(this.key, R.isNil(layoutConfig.children)
            ? [layoutConfig]
            : this.getDefinedChildren(layoutConfig).map(function (item) { return _this.tryCloneItem(item, layoutConfig); }), layoutConfig);
    };
    /**
     * @stable [22.10.2018]
     * @param {IUniversalLayoutBuilderConfiguration<TNode>} layoutConfig
     * @returns {Array<UniversalLayoutBuilderChildrenT<TNode>>}
     */
    UniversalLayoutBuilder.prototype.getDefinedChildren = function (layoutConfig) {
        return layoutConfig.children.filter(function (item) { return !R.isNil(item); });
    };
    /**
     * @stable [22.10.2018]
     * @param {UniversalLayoutBuilderChildrenT<TNode>} item
     * @param {IUniversalLayoutBuilderConfiguration<TNode>} layoutConfig
     * @returns {TNode}
     */
    UniversalLayoutBuilder.prototype.tryCloneItem = function (item, layoutConfig) {
        var itemAsNode = item;
        var itemAsCfg = item;
        return this.layoutViewBuilder.isClonedItem(item)
            ? this.layoutViewBuilder.cloneItem(itemAsNode, this.layoutViewBuilder.getClonedItemProps(itemAsNode, layoutConfig, { key: this.getClonedItemKey(itemAsNode) }))
            : this.buildLayout(itemAsCfg);
    };
    Object.defineProperty(UniversalLayoutBuilder.prototype, "key", {
        /**
         * @stable [22.10.2018]
         * @returns {{key: string}}
         */
        get: function () {
            return { key: this.newKey };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalLayoutBuilder.prototype, "newKey", {
        /**
         * @stable [22.10.2018]
         * @returns {string}
         */
        get: function () {
            return this.layoutId + "-" + this.index++;
        },
        enumerable: true,
        configurable: true
    });
    return UniversalLayoutBuilder;
}());
exports.UniversalLayoutBuilder = UniversalLayoutBuilder;
//# sourceMappingURL=universal-layout.builder.js.map