"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var di_1 = require("../../di");
var date_converter_service_1 = require("./date-converter.service");
var dateConverter = di_1.staticInjector(date_converter_service_1.DateConverter);
describe('date-converter.service', function () {
    describe('fromDateToUiDate', function () {
        // https://www.timeanddate.com/worldclock/converter.html
        it('test1', function () {
            var value = dateConverter.fromDateToUiDate('2036-07-31'); // Moscow, Russia
            expect(value).toEqual('2036-07-31'); // Los Angeles, USA
        });
        it('test2', function () {
            var value = dateConverter.fromDateToUiDate(new Date('2036-07-31')); // Moscow, Russia
            expect(value).toEqual('2036-07-30'); // Los Angeles, USA
        });
    });
    describe('fromDateTimeToUiDate', function () {
        // https://www.timeanddate.com/worldclock/converter.html
        it('test1', function () {
            var value = dateConverter.fromDateTimeToUiDate('2036-07-31T00:00:00+03:00'); // Moscow, Russia
            expect(value).toEqual('2036-07-30'); // Los Angeles, USA
        });
        it('test2', function () {
            var value = dateConverter.fromDateTimeToUiDate(new Date('2036-07-31T00:00:00+03:00')); // Moscow, Russia
            expect(value).toEqual('2036-07-30'); // Los Angeles, USA
        });
    });
    describe('fromDateTimeToUiDateTime', function () {
        // https://www.timeanddate.com/worldclock/converter.html
        it('test1', function () {
            var value = dateConverter.fromDateTimeToUiDateTime('2036-07-31T00:00:00+03:00'); // Moscow, Russia
            expect(value).toEqual('2036-07-30 14:00:00'); // Los Angeles, USA
        });
        it('test2', function () {
            var value = dateConverter.fromDateTimeToUiDateTime(new Date('2036-07-31T00:00:00+03:00')); // Moscow, Russia
            expect(value).toEqual('2036-07-30 14:00:00'); // Los Angeles, USA
        });
    });
    describe('from30DaysAgoUiDateTimeToDateTime', function () {
        it('test1', function () {
            var value = dateConverter.from30DaysAgoUiDateTimeToDateTime();
            expect(value).toEqual('2036-07-31T00:00:00-07:00');
        });
    });
    describe('fromStartUiDateTimeToDateTime', function () {
        it('test1', function () {
            var value = dateConverter.fromStartUiDateTimeToDateTime('2018-01-31');
            expect(value).toEqual('2018-01-31T00:00:00-08:00');
        });
        it('test2', function () {
            var value = dateConverter.fromStartUiDateTimeToDateTime('2018-01-31', '21:58:59');
            expect(value).toEqual('2018-01-31T21:58:59-08:00');
        });
    });
    describe('fromEndUiDateTimeToDateTime', function () {
        it('test1', function () {
            var value = dateConverter.fromEndUiDateTimeToDateTime('2018-01-31');
            expect(value).toEqual('2018-01-31T23:59:59-08:00');
        });
        it('test2', function () {
            var value = dateConverter.fromEndUiDateTimeToDateTime('2018-01-31', '21:58:59');
            expect(value).toEqual('2018-01-31T21:58:59-08:00');
        });
    });
    describe('getCurrentDate', function () {
        it('test1', function () {
            var value = dateConverter.getCurrentDate();
            expect(value).toEqual(new Date('Aug 30 2036 00:00:00 GMT-0800'));
        });
    });
});
//# sourceMappingURL=date-converter.service.spec.js.map