"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var inversify_1 = require("inversify");
var R = require("ramda");
var di_1 = require("../di");
var transport_interface_1 = require("./transport.interface");
var transport_reducer_interface_1 = require("./transport-reducer.interface");
var util_1 = require("../util");
var TransportService = /** @class */ (function () {
    function TransportService() {
    }
    TransportService.prototype.toRequestParams = function (req) {
        return this.transportFactory.toRequestParams(req);
    };
    TransportService.prototype.request = function (req) {
        var _this = this;
        this.onRequest(req);
        return new Promise(function (resolve, reject) { return (_this.transportFactory
            .request(req)
            .then(function (response) {
            var error = response.data.error || response.data.Message;
            if (error) {
                _this.onRequestError(req, error);
                reject(error);
            }
            else {
                var result = (req.reader ? req.reader(response.data) : response.data).result;
                _this.onRequestDone(req, result);
                resolve(result);
            }
        })
            .catch(function (e) {
            if (e === transport_interface_1.TRANSPORT_REQUEST_CANCEL_REASON) {
                _this.onRequestCancel(req);
                // Don't need to worry about unresolved promises as long as you don't have external references to them
            }
            else {
                _this.onRequestError(req, e);
                reject(e);
            }
        })); });
    };
    TransportService.prototype.cancelRequest = function (operationId) {
        this.transportFactory.cancelRequest(operationId);
    };
    TransportService.prototype.onRequest = function (req) {
        this.store.dispatch({
            type: transport_reducer_interface_1.TRANSPORT_REQUEST_ACTION_TYPE,
            data: this.toRequestMetaData(req),
        });
    };
    TransportService.prototype.onRequestDone = function (req, result) {
        var data = __assign({}, this.toRequestMetaData(req), { result: result });
        this.store.dispatch({ type: transport_reducer_interface_1.TRANSPORT_REQUEST_DONE_ACTION_TYPE, data: data });
    };
    /**
     * @stable [17.08.2018]
     * @param {ITransportRequestEntity} req
     */
    TransportService.prototype.onRequestCancel = function (req) {
        this.store.dispatch({ type: transport_reducer_interface_1.TRANSPORT_REQUEST_CANCEL_ACTION_TYPE, data: this.toRequestMetaData(req) });
    };
    TransportService.prototype.onRequestError = function (req, error) {
        var data = __assign({}, this.toRequestMetaData(req), { error: error });
        this.store.dispatch({ type: transport_reducer_interface_1.TRANSPORT_REQUEST_ERROR_ACTION_TYPE, data: data });
    };
    /**
     * @stable [17.08.2018]
     * @param {ITransportRequestEntity} req
     * @returns {ITransportResponseEntity}
     */
    TransportService.prototype.toRequestMetaData = function (req) {
        return util_1.defValuesFilter({
            name: req.name,
            operationId: util_1.orUndef(!R.isNil(req.operation), function () { return req.operation.id; }),
        });
    };
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Store),
        __metadata("design:type", Object)
    ], TransportService.prototype, "store", void 0);
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.TransportFactory),
        __metadata("design:type", Object)
    ], TransportService.prototype, "transportFactory", void 0);
    TransportService = __decorate([
        inversify_1.injectable()
    ], TransportService);
    return TransportService;
}());
exports.TransportService = TransportService;
//# sourceMappingURL=transport.service.js.map